@@ -56,7 +56,7 @@ setredG <- function(
     }
   }
   # Check distance matrix
-  if(class(D) == "dist"){
+  if(inherits(D, "dist")){
     D <- proxy::as.matrix(D)
   }
   if(!is.matrix(D)){
